@@ -34,6 +34,10 @@ def read_offsets_file():
     try:
         with open(offset_file) as json_file:
             offsets = json.load(json_file)
+            print(
+                f"OFFSETS are x:{offsets['x']} y:{offsets['y']} z:{offsets['z']}"
+                f" 100mw_calibration:{offsets['100mw_calibration']}"
+            )
     except FileNotFoundError:
         print("offsets file not found at " + offset_file)
         offsets = {'x': 11.3, 'y': 4.3, 'z': 0.38, "100mw_calibration": 13.88}
